"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

#: List of input files
inp_files = [
"t01.in",
"t02.in",
"t03.in",
"t04.in",
"t05.in",
"t06.in",
"t07.in",
"t08.in",
"t09.in",
"t10.in",
"t11.in",
"t12.in",
"t13.in",
"t14.in",
"t15.in",
"t16.in",
"t17.in",
"t18.in",
"t19.in",
"t20.in",
"t21.in",
"t22.in",
"t23.in",
"t24.in",
"t25.in",
"t26.in",
"t27.in",
"t28.in",
"t29.in",
"t30.in",
"t31.in",
"t32.in",
"t33.in",
"t34.in",
"t35.in",
"t36.in",
"t37.in",
"t38.in",
"t39.in",
"t40.in",
"t41.in",
"t42.in",
"t43.in",
"t44.in",
"t45.in",
"t46.in",
"t47.in",
#"t48.in",
"t49.in",
"t50.in", 
"t51.in", 
"t52.in", 
"t53.in", 
"t54.in", 
"t55.in",
"t56.in",
"t57.in",
"t58.in", 
"t59.in",
"t60.in",
"t61.in",
"t62.in",
"t63.in",
"t64.in",
"t65.in",
"t66.in",
"t67.in",
"t68.in", 
"t69.in",
"t70.in",
"t71.in",
"t72.in",
"t73.in",
"t74.in",
"t75.in",
"t76.in",
"-t77.in",  # Removing?
"t78.in",
"t79.in",
"t80.in",
"t81.in",
"-t85.in",  # Not portable ...   So, at present, prtsrlr is not tested ...
"t89.in",
"t90.in",
"t91.in",
"t92.in",
"t93.in",
"t94.in",
"-t95.in",   # TOOOO SLOW and not portable (to be debugged)
"-t96.in",   # TOOOO SLOW and not portable (to be debugged)
"-t121.in",  # Transfered to seq  
"-t122.in",  # Transfered to seq 
"-t123.in",  # Transfered to seq 
"-t124.in",  # Transfered to seq 
"-t125.in",  # Transfered to seq 
"-t126.in",  # Transfered to seq 
]



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [ 
]

#: List of input files
inp_files = [
"t00.in",
"t01.in",
"t02.in",
"t03.in",
"t04.in",
"t05.in",
"t06.in",
"t07.in",
"t08.in",
"t09.in",
"t11.in",
"t12.in",
"t14.in",
"t16.in",
"t17.in",
"t19.in",
"t20.in",
"t21.in",
"t23.in",
"t24.in",
"t25.in",
"t26.in",
"t27.in",
"t28.in",
"t29.in",
"t30.in",
]



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
"HAVE_MPI",
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

#: This suite contains tests executed with different numbers of MPI processes.
is_multi_parallel = True

subsuites = [
"dfpt",
"gspw",
#"gswvl",
"mbt",
#"dmft",
#"moldyn",
"string",
"ucrpa",
]

#: List of input files
inp_files = [
#"gswvl_01.in",
#"gswvl_02.in",
#"tdfpt_01.in",
#"tdfpt_02.in",
"tdfpt_03.in",
"tdfpt_04.in",
#"tdfpt_03PAW.in,"
#"tdfpt_04PAW.in",
#"tdmft_1.in",
#"tdmft_2.in",
"tgspw_01.in",
"tgspw_02.in",    # OK
"tgspw_03.in",    # OK
#"tgspw_04.in",   # Unstable because nstep=5 and bandpp: 2d iteration oscillates and fldiff does not handle it!
#"tgspw_05.in",
"tmbt_1.in",   # OK     
"tmbt_2.in",   # OK
"tmbt_3.in",   # OK
"tmbt_4.in",   # OK
#"tmbt_5.in",  
#"tmoldyn_01.in",    # This is not stable. Does it use random number generators?
#"tmoldyn_02.in",
#"tmoldyn_03.in",
#"tmoldyn_04.in",
#"tmoldyn_05.in",
#"tmoldyn_06.in",
#"tmoldyn_07.in",
"tstring_01.in",   # MPI Error in MPI_ALLREDUCE
#"tstring_02.in",
#"tstring_03.in",
#"tstring_04.in",
"tucrpa_1.in",
"tucrpa_2.in",
#"tucrpa_3.in",
#"tucrpa_4.in",
#"tucrpa_5.in",
]



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

#: List of input files
inp_files = [
"t01.in",
"t02.in",
"t03.in",
"t04.in",
"t05.in",
"t06.in",
"t07.in",
"t08.in",
"t09.in",
"t17.in",
"t20.in",
"t21.in",
"t22.in",
"t23.in",
"t24.in",
"t25.in",
"t26.in",
"t27.in",
"t28.in",
"t29.in",
"t30.in",
"t31.in",
"t32.in",    
"t33.in",
"t34.in",
"t35.in",
"t36.in",
"-t37.in", # Test 37 is not portable, and has been disabled
"t38.in",
"t39.in",
"t40.in",
"t41.in",
"t42.in",
"t43.in",
"t44.in",
"t45.in",
"t46.in",
"t50.in", 
"t51.in", 
"t52.in",
"t53.in",
"t54.in",
"-t55.in", # Disabled!
"t56.in", 
"t57.in", 
"t58.in",
"t59.in",
"t60.in",
"t61.in",
"t62.in",
"t63.in",
"t64.in",
"t65.in",
"t66.in",
"t67.in",
"t68.in",
"t69.in",
"t70.in",
"t71.in",
"t72.in",
"t73.in",
"t74.in",
"t75.in",
"t76.in",
"t77.in",
"-t78.in", # transferred in seq
"t79.in",
"-t80.in", # transferred in seq
"t81.in",
"t82.in",
"t83.in",
"t84.in",
"t85.in",
"t86.in",
"t87.in",
"t88.in",
"t89.in",
"-t90.in", # transferred in seq
"t91.in",
"t92.in",
"t93.in",
"t94.in",
"t95.in",
"t96.in",  
"t97.in",
"t98.in",
"t99.in",
]



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

#: List of input files
inp_files = [
"t01.in",
"t02.in",
"t03.in",
"t04.in",
"t05.in",
"t06.in",
"t07.in",
"t08.in",
"t09.in",
"t11.in",
"t12.in",
"t13.in",
"t14.in",
"t15.in",
"t16.in",
"t19.in",
"t21.in",
"t22.in",
"t29.in",
"t31.in",
"t32.in",
"t33.in",
"t34.in",
"t35.in",
"t36.in",
"t37.in",
"t38.in",
"t39.in",
"t40.in",
"t41.in",
"t50.in",
"t51.in",
"t52.in",
"t53.in",
]



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite.
keywords = [
]

#: List of input files
inp_files = [
# Constrained DFT
"t01.in",
"t02.in",
"t03.in",
# Structure variable
"t04.in",
# Optic
"t05.in", # GGA-PBE nsppol=1
"t06.in", # optic
"t07.in", # GGA-PBE nsppol=2
"t08.in", # optic
"t09.in", # GGA-PBE PAW nsppol=1
"t10.in", # optic
"t11.in", # GGA-PBE PAW nsppol=2
"t12.in", # optic
"t13.in", # metallic iron GGA-PBE PAW nsppol=2
"t14.in", # optic
"t15.in", # check slight misalignment of rprim, with large tolsym
"t16.in", # check slightly incorrect xred, with large tolsym
"t17.in", # check slightly incorrect rprim and xred, yielding correction to tnons, although stil not tolerated.
"t18.in", # check slightly incorrect rprim and xred, yielding correction to tnons, tolerated.
"t19.in", # disable all checks thanks to expert_user
"t20.in", # test treatment of inaccurate POSCAR file
"t21.in", # test treatment of inaccurate POSCAR file
# GW/BSE
"t31.in", # HF exchange checking q->0 terms
"t32.in", # AC GW
# DFPT
"t41.in",
"t42.in",
"t43.in",
# Electron-phonon
"t50.in",
"t51.in",
"t52.in",
"t53.in",
"t54.in",
"t55.in",
"t56.in",
"t57.in",
"t58.in",
"t59.in",
"t60.in",
"t61.in",
# Spin dynamics in multibinit
"t81.in", # set initial spin using rotation q-modulation
"t82.in", # damping
# New lattice mover in multibinit
"t83.in", # Langevin NVT 
"t84.in", # Berendsen NVT
"t85.in", # Velocity Verlet NVE
"t86.in", # Spin lattice coupling, Only Oiju term activated.
"t87.in", # Spin lattice coupling, Oiju and Tijuv. 
]



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

#: This suite contains tests executed with different numbers of MPI processes.
is_multi_parallel = True


#: List of input files
inp_files = [
#"si_kpt_band_fft.in",
#"t_bandfft.in",
#"t_kpt+spin.in"
"t01.in",
"t02.in",
"t03.in",
"t05.in",
"t06.in", 
"t07.in", 
"t08.in",
"t09.in",
"t21.in",
"t22.in",
"-t23.in", # disabled
"t24.in",
"t25.in",
"t26.in",
"t27.in",
"t28.in",
"t29.in",
"t30.in",
"t31.in",
"t41.in",
"-t48.in", # MPI-IO, not tested here!
"-t49.in", # MPI-IO, not tested here!
"t51.in",
"t52.in",
"t53.in",
"t54.in",
"t55.in",
"t56.in",
"t57.in",
"-t58.in", # disabled
"t59.in",
"t60.in",
"-t61.in", # disabled for now
"t62.in",
"t71.in",
"t72.in",
"t73.in",
"t74.in",
"t75.in",
"t76.in",
"t77.in",
"t80.in",
"t81.in",
"t82.in",
"t83.in",
"t84.in",
"-t85.in", # disabled for now
"t86.in",
"t91.in",
"t92.in",
"t93.in",
"t94.in",
"t95.in",
"t96.in",
"t97.in",
"t98.in",
"t99.in"
]



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
"HAVE_LIBXC",
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
]

#: List of input files
inp_files = [
"t00.in",
"t01.in",
"t02.in",
"t03.in",
"t04.in",
"t05.in",
"t06.in",
"t07.in",
"t08.in",
"t09.in",
"t10.in",
"-t11.in", # Disabled
"-t12.in", # Disabled
"t13.in",
"-t14.in", # Disabled
"-t15.in", # Disabled
"-t16.in", # Disabled
"t17.in",
"t18.in",
"t19.in",
"t20.in",
"t21.in",
"t41.in",
"t42.in", 
"t43.in", 
"t44.in", 
"t45.in", 
"t51.in", 
"t52.in", 
"t53.in",  
"t67.in",  
"t68.in",  
"t69.in",  
"t70.in",  
"t71.in",  
"t72.in", 
"t73.in", 
"t74.in", 
"t81.in", 
"t82.in", 
]



"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
"HAVE_LIBPSML",
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
"PSML"
]

#: List of input files
inp_files = [
"t01.in",
"t02.in",
"t03.in",
"t04.in",
"t05.in",
"t06.in",
"t07.in",
"t08.in",
"t09.in",
"t10.in",
"t11.in",
"t12.in",
"t13.in",
"t14.in",
]
